@@ -737,7 +737,7 @@ def get_K_renorm_old(tot_atoms_uc, N1, N2, N3, H, R0, kpoints, Ds):
     N1N2N3 = N1*N2*N3
     N1N2N3_k = len(kpoints)
     N = N1N2N3 * tot_atoms_uc
-    R_mat = R_matrix(N1,N2,N3,tot_atoms_uc, R0, H)
+    R_mat, R_new = R_matrix(N1,N2,N3,tot_atoms_uc, R0, H)
 
     K_renorm = np.zeros((tot_atoms_uc*3, N*3), dtype=complex)
     for i in range(0,tot_atoms_uc*3,3):
@@ -772,7 +772,7 @@ def get_K_renorm(tot_atoms_uc, N1, N2, N3, H, R0, irr_ks, permutations_types, Ds
     N1N2N3_k = len(Ds[:,0,0])
     N1N2N3 = N1*N2*N3
     N = N1N2N3 * tot_atoms_uc
-    R_mat = R_matrix(N1,N2,N3,tot_atoms_uc, R0, H)
+    R_mat, R_new = R_matrix(N1,N2,N3,tot_atoms_uc, R0, H)
     
     K_renorm = np.zeros((tot_atoms_uc*3, N*3), dtype=complex)
     for i in range(0,tot_atoms_uc*3,3):
@@ -1053,7 +1053,7 @@ def get_D(k, K,N1,N2,N3,R0,masses,tot_atoms_uc, H):
     N1N2N3 = N1 * N2 * N3
     N = N1N2N3*tot_atoms_uc
     
-    R, Rnew = R_matrix(N1,N2,N3,tot_atoms_uc, R0, H)
+    R_old, Rnew = R_matrix(N1,N2,N3,tot_atoms_uc, R0, H)
     #prepare kdotr
     exp_coeff = np.zeros((tot_atoms_uc*3,N*3), dtype=complex)
     for i in range(tot_atoms_uc):
